@@ -18,7 +18,9 @@ let copy conn_number desc reader writer =
         then (
           let header = P.Header.bin_read_t buf ~pos_ref in
           assert (!pos_ref = pos + len);
-          assert (T.Writer.send_bin_prot writer P.Header.bin_writer_t header = Sent ());
+          assert (
+            T.Writer.send_bin_prot writer P.Header.bin_writer_t header
+            = Sent { result = (); bytes = len });
           [%sexp Header (header : P.Header.t)])
         else (
           let msg = P.Message.bin_read_nat0_t buf ~pos_ref in
@@ -32,15 +34,15 @@ let copy conn_number desc reader writer =
               ~buf
               ~pos:!pos_ref
               ~len:left
-            = Sent ());
+            = Sent { result = (); bytes = len });
           let sexp_of_data len =
             let len = (len : Bin_prot.Nat0.t :> int) in
             let disp_len = min 16 len in
             Sexp.List
               ((Sexp.Atom (sprintf "len=%d" len)
                 :: List.init disp_len ~f:(fun i ->
-                  let x = Char.to_int buf.{!pos_ref + i} in
-                  Sexp.Atom (sprintf "%02x" x)))
+                     let x = Char.to_int buf.{!pos_ref + i} in
+                     Sexp.Atom (sprintf "%02x" x)))
                @ if len > disp_len then [ Atom "..." ] else [])
           in
           [%sexp (msg : data P.Message.t)])
@@ -60,17 +62,17 @@ let main ~host ~lport ~dport =
       (Tcp.Where_to_listen.of_port lport)
       ~on_handler_error:`Raise
       (fun _inet s1 ->
-         let num = !n in
-         incr n;
-         let%bind s2 =
-           Tcp.connect_sock (Tcp.Where_to_connect.of_host_and_port { host; port = dport })
-         in
-         let t1 = T.of_fd (Socket.fd s1) ~max_message_size:(1 lsl 30) in
-         let t2 = T.of_fd (Socket.fd s2) ~max_message_size:(1 lsl 30) in
-         Deferred.all_unit
-           [ copy num "client->server" t1.reader t2.writer
-           ; copy num "server->client" t2.reader t1.writer
-           ])
+      let num = !n in
+      incr n;
+      let%bind s2 =
+        Tcp.connect_sock (Tcp.Where_to_connect.of_host_and_port { host; port = dport })
+      in
+      let t1 = T.of_fd (Socket.fd s1) ~max_message_size:(1 lsl 30) in
+      let t2 = T.of_fd (Socket.fd s2) ~max_message_size:(1 lsl 30) in
+      Deferred.all_unit
+        [ copy num "client->server" t1.reader t2.writer
+        ; copy num "server->client" t2.reader t1.writer
+        ])
   in
   Deferred.never ()
 ;;
