@@ -117,13 +117,27 @@ module Protocol = struct
   type query = string [@@deriving bin_io]
   type response = string [@@deriving bin_io]
 
-  let rpc = Rpc.create ~name:"test-rpc-latency" ~version:1 ~bin_query ~bin_response
+  let rpc =
+    Rpc.create
+      ~name:"test-rpc-latency"
+      ~version:1
+      ~bin_query
+      ~bin_response
+      ~include_in_error_count:Only_on_exn
+  ;;
 
   module Quit = struct
     type query = unit [@@deriving bin_io]
     type response = unit [@@deriving bin_io]
 
-    let rpc = Rpc.create ~name:"test-rpc-latency-quit" ~version:1 ~bin_query ~bin_response
+    let rpc =
+      Rpc.create
+        ~name:"test-rpc-latency-quit"
+        ~version:1
+        ~bin_query
+        ~bin_response
+        ~include_in_error_count:Only_on_exn
+    ;;
   end
 end
 
@@ -329,7 +343,6 @@ let server_command =
     ~behave_nicely_in_pipeline:false
 ;;
 
-
 let client_command =
   Command.async_spec
     ~summary:"test client"
@@ -344,7 +357,6 @@ let client_command =
     ~behave_nicely_in_pipeline:false
 ;;
 
-
 let client_long_command =
   Command.async_spec
     ~summary:"long test client"
@@ -359,7 +371,6 @@ let client_long_command =
     ~behave_nicely_in_pipeline:false
 ;;
 
-
 let quit_command =
   Command.async_spec
     ~summary:"test quit"
@@ -368,7 +379,6 @@ let quit_command =
     ~behave_nicely_in_pipeline:false
 ;;
 
-
 let () =
   Command_unix.run
     (Command.group
