@@ -10,13 +10,13 @@ let () =
       upon
         (after (sec 5.))
         (fun () ->
-           let elapsed = Time_float.diff (Time_float.now ()) start in
-           Core.eprintf
-             "num_live_jobs: %7d  nanos per job: %d\n%!"
-             num_live_jobs
-             (Float.iround_nearest_exn
-                (Time_float.Span.to_ns elapsed /. Float.of_int !num_jobs));
-           Ivar.fill finished ());
+          let elapsed = Time_float.diff (Time_float.now ()) start in
+          Core.eprintf
+            "num_live_jobs: %7d  nanos per job: %d\n%!"
+            num_live_jobs
+            (Float.iround_nearest_exn
+               (Time_float.Span.to_ns elapsed /. Float.of_int !num_jobs));
+          Ivar.fill_exn finished ());
       for _ = 1 to num_live_jobs do
         let rec loop () =
           upon Deferred.unit (fun () ->
