@@ -17,6 +17,16 @@ end
 
 include Async_unix (** @open *)
 
+(** {2 Async_log} *)
+
+(* We define [Async_log] using [struct include ... end] rather than as an alias so that we
+   don't have to add [async_log] to downstream jbuild library imports. *)
+module Log = struct
+  include Async_log
+end
+
+include Async_log.Ppx_log_syntax
+
 (** {2 Async_command} *)
 
 (* We define [Command] using [struct include ... end] rather than as an alias so that we
@@ -41,4 +51,3 @@ let%test "Async library initialization does not initialize the scheduler" =
 
 module Expect_test_config = Expect_test_config
 module Expect_test_config_or_error = Expect_test_config_or_error
-module Ppx_log_syntax = Ppx_log_syntax
